ClientOptions

Struct ClientOptions 

pub struct ClientOptions { /* private fields */ }
Ably client options for initialising a REST or Realtime client.

Implementations

Source

impl ClientOptions

pub fn new(s: &str) -> Self

pub fn with_auth_url(url: Url) -> Self

pub fn with_auth_callback(callback: Arc<dyn AuthCallback>) -> Self

pub fn with_key(key: Key) -> Self

Sets the API key.

Example
let client = ably::ClientOptions::new("aaaaaa.bbbbbb:cccccc").rest()?;
pub fn with_token(token: String) -> Self

pub fn client_id(self, client_id: impl Into<String>) -> Result<Self>

Set the client ID, used for identifying this client when publishing messages or for presence purposes. Can be any utf-8 string except the reserved wildcard string ‘*’.

pub fn use_token_auth(self, v: bool) -> Self

Indicates whether token authentication should be used even if an API key is present.

pub fn environment(self, environment: impl Into<String>) -> Result<Self>

Sets the environment. See [TO3k1].

Example
let client = ably::ClientOptions::new("aaaaaa.bbbbbb:cccccc")
    .environment("sandbox")?
    .rest()?;
Errors

Fails if rest_host is already set or if the environment cannot be used in the REST API URL.

pub fn use_binary_protocol(self, v: bool) -> Self

Sets the message format to MessagePack if the argument is true, or JSON if the argument is false.

pub fn default_token_params(self, params: TokenParams) -> Self

Set the default TokenParams.

pub fn rest_host(self, rest_host: impl Into<String>) -> Result<Self>

Sets the rest_host. See [TO3k2].

Example
let client = ably::ClientOptions::new("aaaaaa.bbbbbb:cccccc")
    .rest_host("sandbox-rest.ably.io")?
    .rest()?;
Errors

Fails if environment is already set or if the rest_host cannot be used in the REST API URL.

pub fn fallback_hosts(self, hosts: Vec<String>) -> Self

Sets the fallback hosts.

pub fn http_request_timeout(self, timeout: Duration) -> Self

Sets the HTTP request timeout.

pub fn http_max_retry_count(self, count: usize) -> Self

Sets the maximum number of HTTP retries.

pub fn rest(self) -> Result<Rest>

Returns a Rest client using the ClientOptions.

Errors

This method fails if the ClientOptions are not valid:

  • the REST API URL must be valid
pub fn token_source(token: Credential) -> Self